
/**
 *	@file		XmlException.d
 *	@version	v1.06
 *	@date		14.10.2004
 * @author	Miguel Ferreira Simoes
 *        
 *	This software is provided 'as-is', without any express or implied
 *	warranty. In no event will the authors be held liable for damages
 *	of any kind arising from the use of this software.
 *      
 *	Permission is hereby granted to anyone to use this software for any 
 *	purpose, including commercial applications, and to alter it and/or 
 *	redistribute it freely, subject to the following restrictions:
 *       
 *	1. The origin of this software must not be misrepresented; you must 
 *		not claim that you wrote the original software.
 *	2. Altered source versions must be plainly marked as such, and must 
 *		not be misrepresented as being the original software.
 *	3.	This notice may not be removed or altered from any distribution
 *		of the source.
 *
 */

module xml.XmlException;

public import std.string;

/**
 * @class XmlException
 * This class is supposed to implement the project exception class.
 * This class is derived from Exception in order to maintain coherence.
 *
 * All xml exception messages are restricted to the ones specified in this class.
 * Optionally line number can be included in the exception message.
 */

class XmlException : Exception {

	/* Private Data */

	/// Contains all possible exception's messages.

	private static const char[][] _messages = [ "xml is not well-formed.",
																		"reading element name.",
																		"reading element attributes.",
																		"reading end tag.",
																		"parsing processing instruction."
																		"unrecognized element tag." ];															

	/// Enum type containing the index of the message.

	public enum Type {
		formed,
		name,
		attributes,
		endTag,
		processingInstruction,
		unrecognizedTag
	}
	
	/* Constructors */
	
	/**
	 * Constructor.
	 * @param type Enum type containing the index of the message.
	 */
																		
	public this (Type type) {
		super(_messages[type]);
	}

	/**
	 * Constructor.
	 * @param type Enum type containing the index of the message.
	 * @param line Line number where the the exception was raised (xml stream).
	 */
	
	public this (Type type, uint line) {
		super(_messages[type] ~ " (line " ~ std.string.toString(line) ~ ")");
	}
																			
}

